pub enum SP5W {
_0,
_1,
}Expand description
Values that can be written to the field SP5
Variants
_0
This peripheral does not require supervisor privilege level for accesses.
_1
This peripheral requires supervisor privilege level for accesses.