pub struct R { /* private fields */ }Expand description
Value read from the register
Implementations
Sourceimpl R
impl R
Sourcepub fn time_stamp(&self) -> TIME_STAMPR
pub fn time_stamp(&self) -> TIME_STAMPR
Bits 0:15 - Free-Running Counter Time stamp. This 16-bit field is a copy of the Free-Running Timer, captured for Tx and Rx frames at the time when the beginning of the Identifier field appears on the CAN bus.