Module ctrlhu

Module ctrlhu 

CRC_CTRLHU register.

Structs

R
Value read from the register
W
Value to write to the register
_FXORW
Proxy
_TCRCW
Proxy
_TOTRW
Proxy
_TOTW
Proxy
_WASW
Proxy

Enums

FXORR
Possible values of the field FXOR
FXORW
Values that can be written to the field FXOR
TCRCR
Possible values of the field TCRC
TCRCW
Values that can be written to the field TCRC
TOTR
Possible values of the field TOT
TOTRR
Possible values of the field TOTR
TOTRW
Values that can be written to the field TOTR
TOTW
Values that can be written to the field TOT
WASR
Possible values of the field WAS
WASW
Values that can be written to the field WAS