FSLACCR

Enum FSLACCR 

pub enum FSLACCR {
    _10,
    _11,
    _Reserved(u8),
}
Possible values of the field FSLACC

Variants



_10

Freescale factory access denied



_11

Freescale factory access granted



_Reserved(u8)

Reserved

Implementations

Source

impl FSLACCR

pub fn bits(&self) -> u8

Value of the field as raw bits

pub fn is_10(&self) -> bool

Checks if the value of the field is _10

pub fn is_11(&self) -> bool

Checks if the value of the field is _11