pub enum CH2OCW {
_0,
_1,
}Expand description
Values that can be written to the field CH2OC
Variants
_0
The channel output is not affected by software output control.
_1
The channel output is affected by software output control.