FAULTMR

Enum FAULTMR 

pub enum FAULTMR {
    _00,
    _01,
    _10,
    _11,
}
Possible values of the field FAULTM

Variants



_00

Fault control is disabled for all channels.



_01

Fault control is enabled for even channels only (channels 0, 2, 4, and 6), and the selected mode is the manual fault clearing.



_10

Fault control is enabled for all channels, and the selected mode is the manual fault clearing.



_11

Fault control is enabled for all channels, and the selected mode is the automatic fault clearing.

Implementations

Source

impl FAULTMR

pub fn bits(&self) -> u8

Value of the field as raw bits

pub fn is_00(&self) -> bool

Checks if the value of the field is _00

pub fn is_01(&self) -> bool

Checks if the value of the field is _01

pub fn is_10(&self) -> bool

Checks if the value of the field is _10

pub fn is_11(&self) -> bool

Checks if the value of the field is _11