PSR

Enum PSR 

pub enum PSR {
    _000,
    _001,
    _010,
    _011,
    _100,
    _101,
    _110,
    _111,
}
Possible values of the field PS

Variants



_000

Divide by 1



_001

Divide by 2



_010

Divide by 4



_011

Divide by 8



_100

Divide by 16



_101

Divide by 32



_110

Divide by 64



_111

Divide by 128

Implementations

Source

impl PSR

pub fn bits(&self) -> u8

Value of the field as raw bits

pub fn is_000(&self) -> bool

Checks if the value of the field is _000

pub fn is_001(&self) -> bool

Checks if the value of the field is _001

pub fn is_010(&self) -> bool

Checks if the value of the field is _010

pub fn is_011(&self) -> bool

Checks if the value of the field is _011

pub fn is_100(&self) -> bool

Checks if the value of the field is _100

pub fn is_101(&self) -> bool

Checks if the value of the field is _101

pub fn is_110(&self) -> bool

Checks if the value of the field is _110

pub fn is_111(&self) -> bool

Checks if the value of the field is _111