pub enum INVCW {
_0,
_1,
}Expand description
Values that can be written to the field INVC
Variants
_0
INVCTRL register is updated with its buffer value at all rising edges of system clock.
_1
INVCTRL register is updated with its buffer value by the PWM synchronization.