pub enum SWOCR {
_0,
_1,
}Expand description
Possible values of the field SWOC
Variants
_0
SWOCTRL register is updated with its buffer value at all rising edges of system clock.
_1
SWOCTRL register is updated with its buffer value by the PWM synchronization.
Implementations
Sourceimpl SWOCR
impl SWOCR
Sourcepub fn bit_is_clear(&self) -> bool
pub fn bit_is_clear(&self) -> bool
Returns true if the bit is clear (0)
Sourcepub fn bit_is_set(&self) -> bool
pub fn bit_is_set(&self) -> bool
Returns true if the bit is set (1)