pub enum PHBPOLR {
_0,
_1,
}Expand description
Possible values of the field PHBPOL
Variants
_0
Normal polarity. Phase B input signal is not inverted before identifying the rising and falling edges of this signal.
_1
Inverted polarity. Phase B input signal is inverted before identifying the rising and falling edges of this signal.
Implementations
Sourceimpl PHBPOLR
impl PHBPOLR
Sourcepub fn bit_is_clear(&self) -> bool
pub fn bit_is_clear(&self) -> bool
Returns true if the bit is clear (0)
Sourcepub fn bit_is_set(&self) -> bool
pub fn bit_is_set(&self) -> bool
Returns true if the bit is set (1)