pub enum CH2OCR {
_0,
_1,
}Expand description
Possible values of the field CH2OC
Variants
_0
The channel output is not affected by software output control.
_1
The channel output is affected by software output control.
Implementations
Sourceimpl CH2OCR
impl CH2OCR
Sourcepub fn bit_is_clear(&self) -> bool
pub fn bit_is_clear(&self) -> bool
Returns true if the bit is clear (0)
Sourcepub fn bit_is_set(&self) -> bool
pub fn bit_is_set(&self) -> bool
Returns true if the bit is set (1)