pub enum SBRCW {
_0,
_1,
}Expand description
Values that can be written to the field SBRC
Variants
_0
The slave baud rate follows the master baud rate and clock stretching may occur
_1
Slave baud rate is independent of the master baud rate