pub enum OSCER {
_0,
_1,
}Expand description
Possible values of the field OSCE
Variants
_0
32.768 kHz oscillator is disabled.
_1
32.768 kHz oscillator is enabled. After setting this bit, wait the oscillator startup time before enabling the time counter to allow the 32.768 kHz clock time to stabilize.
Implementations
Sourceimpl OSCER
impl OSCER
Sourcepub fn bit_is_clear(&self) -> bool
pub fn bit_is_clear(&self) -> bool
Returns true if the bit is clear (0)
Sourcepub fn bit_is_set(&self) -> bool
pub fn bit_is_set(&self) -> bool
Returns true if the bit is set (1)