pub enum UMW {
_0,
_1,
}Expand description
Values that can be written to the field UM
Variants
_0
Registers cannot be written when locked.
_1
Registers can be written when locked under limited conditions.