pub enum TSRWW {
_0,
_1,
}Expand description
Values that can be written to the field TSRW
Variants
_0
Writes to the Time Seconds Register are ignored.
_1
Writes to the Time Seconds Register complete as normal.