SDCLKFSR

Enum SDCLKFSR 

pub enum SDCLKFSR {
    _1,
    _10,
    _100,
    _1000,
    _10000,
    _100000,
    _1000000,
    _10000000,
    _Reserved(u8),
}
Possible values of the field SDCLKFS

Variants



_1

Base clock divided by 2.



_10

Base clock divided by 4.



_100

Base clock divided by 8.



_1000

Base clock divided by 16.



_10000

Base clock divided by 32.



_100000

Base clock divided by 64.



_1000000

Base clock divided by 128.



_10000000

Base clock divided by 256.



_Reserved(u8)

Reserved

Implementations

Source

impl SDCLKFSR

pub fn bits(&self) -> u8

Value of the field as raw bits

pub fn is_1(&self) -> bool

Checks if the value of the field is _1

pub fn is_10(&self) -> bool

Checks if the value of the field is _10

pub fn is_100(&self) -> bool

Checks if the value of the field is _100

pub fn is_1000(&self) -> bool

Checks if the value of the field is _1000

pub fn is_10000(&self) -> bool

Checks if the value of the field is _10000

pub fn is_100000(&self) -> bool

Checks if the value of the field is _100000

pub fn is_1000000(&self) -> bool

Checks if the value of the field is _1000000

pub fn is_10000000(&self) -> bool

Checks if the value of the field is _10000000