RAMSIZER

Enum RAMSIZER 

pub enum RAMSIZER {
    _0001,
    _0011,
    _0100,
    _0101,
    _0110,
    _0111,
    _1000,
    _1001,
    _1011,
    _Reserved(u8),
}
Possible values of the field RAMSIZE

Variants



_0001

8 KB



_0011

16 KB



_0100

24 KB



_0101

32 KB



_0110

48 KB



_0111

64 KB



_1000

96 KB



_1001

128 KB



_1011

256 KB



_Reserved(u8)

Reserved

Implementations

Source

impl RAMSIZER

pub fn bits(&self) -> u8

Value of the field as raw bits

pub fn is_0001(&self) -> bool

Checks if the value of the field is _0001

pub fn is_0011(&self) -> bool

Checks if the value of the field is _0011

pub fn is_0100(&self) -> bool

Checks if the value of the field is _0100

pub fn is_0101(&self) -> bool

Checks if the value of the field is _0101

pub fn is_0110(&self) -> bool

Checks if the value of the field is _0110

pub fn is_0111(&self) -> bool

Checks if the value of the field is _0111

pub fn is_1000(&self) -> bool

Checks if the value of the field is _1000

pub fn is_1001(&self) -> bool

Checks if the value of the field is _1001

pub fn is_1011(&self) -> bool

Checks if the value of the field is _1011