Module pmctrl

Module pmctrl 

Power Mode Control register

Structs

R
Value read from the register
W
Value to write to the register
_LPWUIW
Proxy
_RUNMW
Proxy
_STOPMW
Proxy

Enums

LPWUIR
Possible values of the field LPWUI
LPWUIW
Values that can be written to the field LPWUI
RUNMR
Possible values of the field RUNM
RUNMW
Values that can be written to the field RUNM
STOPAR
Possible values of the field STOPA
STOPMR
Possible values of the field STOPM
STOPMW
Values that can be written to the field STOPM