pub enum M10W {
_0,
_1,
}Expand description
Values that can be written to the field M10
Variants
_0
The parity bit is the ninth bit in the serial transmission.
_1
The parity bit is the tenth bit in the serial transmission.