pub enum RDRFR {
_0,
_1,
}Expand description
Possible values of the field RDRF
Variants
_0
The number of datawords in the receive buffer is less than the number indicated by RXWATER.
_1
The number of datawords in the receive buffer is equal to or greater than the number indicated by RXWATER at some point in time since this flag was last cleared.
Implementations
Sourceimpl RDRFR
impl RDRFR
Sourcepub fn bit_is_clear(&self) -> bool
pub fn bit_is_clear(&self) -> bool
Returns true if the bit is clear (0)
Sourcepub fn bit_is_set(&self) -> bool
pub fn bit_is_set(&self) -> bool
Returns true if the bit is set (1)