pub enum TDRER {
_0,
_1,
}Expand description
Possible values of the field TDRE
Variants
_0
The amount of data in the transmit buffer is greater than the value indicated by TWFIFO[TXWATER].
_1
The amount of data in the transmit buffer is less than or equal to the value indicated by TWFIFO[TXWATER] at some point in time since the flag has been cleared.
Implementations
Sourceimpl TDRER
impl TDRER
Sourcepub fn bit_is_clear(&self) -> bool
pub fn bit_is_clear(&self) -> bool
Returns true if the bit is clear (0)
Sourcepub fn bit_is_set(&self) -> bool
pub fn bit_is_set(&self) -> bool
Returns true if the bit is set (1)