pub enum RWUW {
_0,
_1,
}Expand description
Values that can be written to the field RWU
Variants
_0
Normal operation.
_1
RWU enables the wakeup function and inhibits further receiver interrupt requests. Normally, hardware wakes the receiver by automatically clearing RWU.