pub enum TDMASW {
_0,
_1,
}Expand description
Values that can be written to the field TDMAS
Variants
_0
If C2[TIE] is set and the S1[TDRE] flag is set, the TDRE interrupt request signal is asserted to request interrupt service.
_1
If C2[TIE] is set and the S1[TDRE] flag is set, the TDRE DMA request signal is asserted to request a DMA transfer.