Module c1

Module c1 

UART Control Register 1

Structs

R
Value read from the register
W
Value to write to the register
_ILTW
Proxy
_LOOPSW
Proxy
_MW
Proxy
_PEW
Proxy
_PTW
Proxy
_RSRCW
Proxy
_UARTSWAIW
Proxy
_WAKEW
Proxy

Enums

ILTR
Possible values of the field ILT
ILTW
Values that can be written to the field ILT
LOOPSR
Possible values of the field LOOPS
LOOPSW
Values that can be written to the field LOOPS
MR
Possible values of the field M
MW
Values that can be written to the field M
PER
Possible values of the field PE
PEW
Values that can be written to the field PE
PTR
Possible values of the field PT
PTW
Values that can be written to the field PT
RSRCR
Possible values of the field RSRC
RSRCW
Values that can be written to the field RSRC
UARTSWAIR
Possible values of the field UARTSWAI
UARTSWAIW
Values that can be written to the field UARTSWAI
WAKER
Possible values of the field WAKE
WAKEW
Values that can be written to the field WAKE