pub struct _MAEN2W<'a> { /* private fields */ }Expand description
Proxy
Implementations
Sourceimpl<'a> _MAEN2W<'a>
impl<'a> _MAEN2W<'a>
Sourcepub fn _0(self) -> &'a mut W
pub fn _0(self) -> &'a mut W
All data received is transferred to the data buffer if MAEN1 is cleared.
Sourcepub fn _1(self) -> &'a mut W
pub fn _1(self) -> &'a mut W
All data received with the most significant bit cleared, is discarded. All data received with the most significant bit set, is compared with contents of MA2 register. If no match occurs, the data is discarded. If a match occurs, data is transferred to the data buffer. This field must be cleared when C7816[ISO7816E] is set/enabled.