pub enum TXOFEW {
_0,
_1,
}Expand description
Values that can be written to the field TXOFE
Variants
_0
TXOF flag does not generate an interrupt to the host.
_1
TXOF flag generates an interrupt to the host.