TXFIFOSIZER

Enum TXFIFOSIZER 

pub enum TXFIFOSIZER {
    _000,
    _001,
    _010,
    _011,
    _100,
    _101,
    _110,
    _Reserved(u8),
}
Possible values of the field TXFIFOSIZE

Variants



_000

Transmit FIFO/Buffer depth = 1 dataword.



_001

Transmit FIFO/Buffer depth = 4 datawords.



_010

Transmit FIFO/Buffer depth = 8 datawords.



_011

Transmit FIFO/Buffer depth = 16 datawords.



_100

Transmit FIFO/Buffer depth = 32 datawords.



_101

Transmit FIFO/Buffer depth = 64 datawords.



_110

Transmit FIFO/Buffer depth = 128 datawords.



_Reserved(u8)

Reserved

Implementations

Source

impl TXFIFOSIZER

pub fn bits(&self) -> u8

Value of the field as raw bits

pub fn is_000(&self) -> bool

Checks if the value of the field is _000

pub fn is_001(&self) -> bool

Checks if the value of the field is _001

pub fn is_010(&self) -> bool

Checks if the value of the field is _010

pub fn is_011(&self) -> bool

Checks if the value of the field is _011

pub fn is_100(&self) -> bool

Checks if the value of the field is _100

pub fn is_101(&self) -> bool

Checks if the value of the field is _101

pub fn is_110(&self) -> bool

Checks if the value of the field is _110