pub enum NFR {
_0,
_1,
}Expand description
Possible values of the field NF
Variants
_0
No noise detected since the last time this flag was cleared. If the receive buffer has a depth greater than 1 then there may be data in the receiver buffer that was received with noise.
_1
At least one dataword was received with noise detected since the last time the flag was cleared.
Implementations
Sourceimpl NFR
impl NFR
Sourcepub fn bit_is_clear(&self) -> bool
pub fn bit_is_clear(&self) -> bool
Returns true if the bit is clear (0)
Sourcepub fn bit_is_set(&self) -> bool
pub fn bit_is_set(&self) -> bool
Returns true if the bit is set (1)