pub enum RXEDGIFW {
_0,
_1,
}Expand description
Values that can be written to the field RXEDGIF
Variants
_0
No active edge on the receive pin has occurred.
_1
An active edge on the receive pin has occurred.