pub enum RXOFW {
_0,
_1,
}Expand description
Values that can be written to the field RXOF
Variants
_0
No receive buffer overflow has occurred since the last time the flag was cleared.
_1
At least one receive buffer overflow has occurred since the last time the flag was cleared.