pub enum RDMASW {
_0,
_1,
}Expand description
Values that can be written to the field RDMAS
Variants
_0
If C2[RIE] and S1[RDRF] are set, the RDFR interrupt request signal is asserted to request an interrupt service.
_1
If C2[RIE] and S1[RDRF] are set, the RDRF DMA request signal is asserted to request a DMA transfer.