pub enum RXOFEW {
_0,
_1,
}Expand description
Values that can be written to the field RXOFE
Variants
_0
RXOF flag does not generate an interrupt to the host.
_1
RXOF flag generates an interrupt to the host.