TXRTSEW

Enum TXRTSEW 

pub enum TXRTSEW {
    _0,
    _1,
}
Values that can be written to the field TXRTSE

Variants



_0

The transmitter has no effect on RTS.



_1

When a character is placed into an empty transmitter data buffer , RTS asserts one bit time before the start bit is transmitted. RTS deasserts one bit time after all characters in the transmitter data buffer and shift register are completely sent, including the last stop bit. (FIFO) (FIFO)