pub enum PFR {
_0,
_1,
}Expand description
Possible values of the field PF
Variants
_0
No parity error detected since the last time this flag was cleared. If the receive buffer has a depth greater than 1, then there may be data in the receive buffer what was received with a parity error.
_1
At least one dataword was received with a parity error since the last time this flag was cleared.
Implementations
Sourceimpl PFR
impl PFR
Sourcepub fn bit_is_clear(&self) -> bool
pub fn bit_is_clear(&self) -> bool
Returns true if the bit is clear (0)
Sourcepub fn bit_is_set(&self) -> bool
pub fn bit_is_set(&self) -> bool
Returns true if the bit is set (1)