RXRTSER

Enum RXRTSER 

pub enum RXRTSER {
    _0,
    _1,
}
Possible values of the field RXRTSE

Variants



_0

The receiver has no effect on RTS.



_1

RTS is deasserted if the number of characters in the receiver data register (FIFO) is equal to or greater than RWFIFO[RXWATER]. RTS is asserted when the number of characters in the receiver data register (FIFO) is less than RWFIFO[RXWATER].

Implementations

Source

impl RXRTSER

pub fn bit_is_clear(&self) -> bool

Returns true if the bit is clear (0)

pub fn bit_is_set(&self) -> bool

Returns true if the bit is set (1)

pub fn bit(&self) -> bool

Value of the field as raw bits

pub fn is_0(&self) -> bool

Checks if the value of the field is _0

pub fn is_1(&self) -> bool

Checks if the value of the field is _1