pub enum RXEDGIFR {
_0,
_1,
}Expand description
Possible values of the field RXEDGIF
Variants
_0
No active edge on the receive pin has occurred.
_1
An active edge on the receive pin has occurred.
Implementations
Sourceimpl RXEDGIFR
impl RXEDGIFR
Sourcepub fn bit_is_clear(&self) -> bool
pub fn bit_is_clear(&self) -> bool
Returns true if the bit is clear (0)
Sourcepub fn bit_is_set(&self) -> bool
pub fn bit_is_set(&self) -> bool
Returns true if the bit is set (1)