pub enum BSESSENDW {
_0,
_1,
}Expand description
Values that can be written to the field BSESSEND
Variants
_0
The VBUS voltage is above the B session end threshold.
_1
The VBUS voltage is below the B session end threshold.