MODE_LVR

Enum MODE_LVR 

pub enum MODE_LVR {
    _00,
    _01,
    _10,
    _Reserved(u8),
}
Possible values of the field MODE_LV

Variants



_00

Bandgap on only, for stabilization and startup



_01

High power buffer mode enabled



_10

Low-power buffer mode enabled



_Reserved(u8)

Reserved

Implementations

Source

impl MODE_LVR

pub fn bits(&self) -> u8

Value of the field as raw bits

pub fn is_00(&self) -> bool

Checks if the value of the field is _00

pub fn is_01(&self) -> bool

Checks if the value of the field is _01

pub fn is_10(&self) -> bool

Checks if the value of the field is _10