pub enum OPEW {
_0,
_1,
}Expand description
Values that can be written to the field OPE
Variants
_0
CMPO is not available on the associated CMPO output pin. If the comparator does not own the pin, this field has no effect.
_1
CMPO is available on the associated CMPO output pin. The comparator output (CMPO) is driven out on the associated CMPO output pin if the comparator owns the pin. If the comparator does not own the field, this bit has no effect.