pub enum FAULTMR {
_00,
_01,
_10,
_11,
}Expand description
Possible values of the field FAULTM
Variants
_00
Fault control is disabled for all channels.
_01
Fault control is enabled for even channels only (channels 0, 2, 4, and 6), and the selected mode is the manual fault clearing.
_10
Fault control is enabled for all channels, and the selected mode is the manual fault clearing.
_11
Fault control is enabled for all channels, and the selected mode is the automatic fault clearing.
Implementations