pub enum MAEN2W {
_0,
_1,
}Expand description
Values that can be written to the field MAEN2
Variants
_0
All data received is transferred to the data buffer if MAEN1 is cleared.
_1
All data received with the most significant bit cleared, is discarded. All data received with the most significant bit set, is compared with contents of MA2 register. If no match occurs, the data is discarded. If a match occurs, data is transferred to the data buffer. This field must be cleared when C7816[ISO7816E] is set/enabled.