pub enum RXRTSER {
_0,
_1,
}Expand description
Possible values of the field RXRTSE
Variants
_0
The receiver has no effect on RTS.
_1
RTS is deasserted if the number of characters in the receiver data register (FIFO) is equal to or greater than RWFIFO[RXWATER]. RTS is asserted when the number of characters in the receiver data register (FIFO) is less than RWFIFO[RXWATER].
Implementations
Sourceimpl RXRTSER
impl RXRTSER
Sourcepub fn bit_is_clear(&self) -> bool
pub fn bit_is_clear(&self) -> bool
Returns true if the bit is clear (0)
Sourcepub fn bit_is_set(&self) -> bool
pub fn bit_is_set(&self) -> bool
Returns true if the bit is set (1)